==> aliyun-java-sdk-edas-2.16.0-sources.jar: com/aliyuncs/edas/transform/v20170801/GetContainerConfigurationResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.edas.transform.v20170801;

import com.aliyuncs.edas.model.v20170801.GetContainerConfigurationResponse;
import com.aliyuncs.edas.model.v20170801.GetContainerConfigurationResponse.ContainerConfiguration;
import com.aliyuncs.transform.UnmarshallerContext;


public class GetContainerConfigurationResponseUnmarshaller {

	public static GetContainerConfigurationResponse unmarshall(GetContainerConfigurationResponse getContainerConfigurationResponse, UnmarshallerContext context) {
		
		getContainerConfigurationResponse.setCode(context.integerValue("GetContainerConfigurationResponse.Code"));
		getContainerConfigurationResponse.setMessage(context.stringValue("GetContainerConfigurationResponse.Message"));

		ContainerConfiguration containerConfiguration = new ContainerConfiguration();
		containerConfiguration.setContextPath(context.stringValue("GetContainerConfigurationResponse.ContainerConfiguration.ContextPath"));
		containerConfiguration.setHttpPort(context.integerValue("GetContainerConfigurationResponse.ContainerConfiguration.HttpPort"));
		containerConfiguration.setMaxThreads(context.integerValue("GetContainerConfigurationResponse.ContainerConfiguration.MaxThreads"));
		containerConfiguration.setURIEncoding(context.stringValue("GetContainerConfigurationResponse.ContainerConfiguration.URIEncoding"));
		containerConfiguration.setUseBodyEncoding(context.booleanValue("GetContainerConfigurationResponse.ContainerConfiguration.UseBodyEncoding"));
		getContainerConfigurationResponse.setContainerConfiguration(containerConfiguration);
	 
	 	return getContainerConfigurationResponse;
	}
}

==> aliyun-java-sdk-edas-2.44.0-sources.jar: com/aliyuncs/edas/transform/v20170801/GetContainerConfigurationResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.edas.transform.v20170801;

import com.aliyuncs.edas.model.v20170801.GetContainerConfigurationResponse;
import com.aliyuncs.edas.model.v20170801.GetContainerConfigurationResponse.ContainerConfiguration;
import com.aliyuncs.transform.UnmarshallerContext;


public class GetContainerConfigurationResponseUnmarshaller {

	public static GetContainerConfigurationResponse unmarshall(GetContainerConfigurationResponse getContainerConfigurationResponse, UnmarshallerContext context) {
		
		getContainerConfigurationResponse.setRequestId(context.stringValue("GetContainerConfigurationResponse.RequestId"));
		getContainerConfigurationResponse.setCode(context.integerValue("GetContainerConfigurationResponse.Code"));
		getContainerConfigurationResponse.setMessage(context.stringValue("GetContainerConfigurationResponse.Message"));

		ContainerConfiguration containerConfiguration = new ContainerConfiguration();
		containerConfiguration.setContextPath(context.stringValue("GetContainerConfigurationResponse.ContainerConfiguration.ContextPath"));
		containerConfiguration.setHttpPort(context.integerValue("GetContainerConfigurationResponse.ContainerConfiguration.HttpPort"));
		containerConfiguration.setMaxThreads(context.integerValue("GetContainerConfigurationResponse.ContainerConfiguration.MaxThreads"));
		containerConfiguration.setURIEncoding(context.stringValue("GetContainerConfigurationResponse.ContainerConfiguration.URIEncoding"));
		containerConfiguration.setUseBodyEncoding(context.booleanValue("GetContainerConfigurationResponse.ContainerConfiguration.UseBodyEncoding"));
		getContainerConfigurationResponse.setContainerConfiguration(containerConfiguration);
	 
	 	return getContainerConfigurationResponse;
	}
}
